LevelDataManager

Struct LevelDataManager 

pub struct LevelDataManager {
    path: Option<PathBuf>,
    data: LevelData,
    dirty: bool,
}
Manages level data persistence for a world.

Fields

path: Option<PathBuf>

Path to the level.toml file.

data: LevelData

Cached level data.

dirty: bool

Whether data has been modified since last save.

Implementations

Source

impl LevelDataManager

pub async fn new( world_dir: Option<impl AsRef<Path>>, seed: i64, difficulty: Difficulty, generation: WorldGenerationSettings, ) -> Result<Self>

Creates a new level data manager for the given world directory.

If level.toml exists, it will be loaded (the provided seed is ignored). Otherwise, new data will be created with the provided seed.

pub async fn load_seed_or_default( world_dir: Option<impl AsRef<Path>>, default_seed: i64, ) -> Result<i64>

Loads the saved world seed from level.toml, or returns the provided default.

pub const fn data(&self) -> &LevelData

Gets a reference to the level data.

pub const fn data_mut(&mut self) -> &mut LevelData

Gets a mutable reference to the level data and marks it as dirty.

pub const fn is_dirty(&self) -> bool

Returns whether the data has been modified since last save.

pub const fn mark_dirty(&mut self)

Marks the data as dirty (needs saving).

pub async fn save(&mut self) -> Result<()>

Saves the level data to disk if it has been modified.

pub const fn seed(&self) -> i64

Gets the seed.

pub const fn game_time(&self) -> i64

Gets the game time.

pub const fn set_game_time(&mut self, time: i64)

Sets the game time.

pub(crate) const fn world_clocks(&self) -> &WorldClockManager

Returns this world’s clock manager.

pub(crate) const fn world_clocks_mut(&mut self) -> &mut WorldClockManager

Returns this world’s mutable clock manager and marks level data dirty.

pub const fn clear_weather_time(&self) -> i32

Gets the clear weather time

pub const fn set_clear_weather_time(&mut self, time: i32)

Sets the clear weather time

pub const fn rain_time(&self) -> i32

Gets the rain time

pub const fn set_rain_time(&mut self, time: i32)

Sets the rain time

pub const fn thunder_time(&self) -> i32

Gets the thunder time

pub const fn set_thunder_time(&mut self, time: i32)

Sets the thunder time

pub const fn is_raining(&self) -> bool

Checks if it’s raining

pub const fn set_raining(&mut self, raining: bool)

Sets whether it’s raining

pub const fn is_thundering(&self) -> bool

Checks if it’s thundering

pub const fn set_thundering(&mut self, thundering: bool)

Sets whether it’s thundering