pub struct WorldGenerationSettings {
pub generator: Identifier,
pub config: Value,
pub dimension_type: Identifier,
pub min_y: i32,
pub height: i32,
}Expand description
Persisted generator metadata used to reject incompatible config changes.
Fields
generator: IdentifierGenerator factory identifier.
config: ValueGenerator config after applying generator defaults.
dimension_type: IdentifierDimension type used by the generator output.
min_y: i32Minimum build Y for the dimension type.
height: i32Total build height for the dimension type.
Implementations
Sourceimpl WorldGenerationSettings
impl WorldGenerationSettings
Sourcepub fn from_generator_config(
generator: Identifier,
config: &Value,
dimension_type: Identifier,
min_y: i32,
height: i32,
) -> Self
pub fn from_generator_config( generator: Identifier, config: &Value, dimension_type: Identifier, min_y: i32, height: i32, ) -> Self
Builds persisted generator metadata from the resolved startup config.